@@ -27,6 +27,7 @@
 html_vignette <- function(fig_width = 3,
                           fig_height = 3,
                           dev = 'png',
+                          df_print = "default",
                           css = NULL,
                           keep_md = FALSE,
                           readme = FALSE,
@@ -51,6 +52,7 @@ html_vignette <- function(fig_width = 3,
   output_format(
     knitr = NULL,
     pandoc = NULL,
+    df_print = df_print,
     pre_knit = pre_knit,
     keep_md = keep_md,
     base_format = html_document(fig_width = fig_width,
