@@ -494,6 +494,30 @@ pandoc_html_navigation_args <- function(self_contained,
             "--variable", paste("navigationjs=", navigation_path, sep=""))
 }
 
+pandoc_html_pagedtable_args <- function(df_print,
+                                        template,
+                                        self_contained,
+                                        files_dir,
+                                        output_dir) {
+  args <- c()
+
+  if (identical(df_print, "paged")) {
+    pagedtable_path <- rmarkdown_system_file("rmd/h/pagedtable-0.0.1")
+    if (self_contained)
+      pagedtable_path <- pandoc_path_arg(pagedtable_path)
+    else
+    {
+      pagedtable_path <- normalized_relative_to(output_dir,
+                                                render_supporting_files(pagedtable_path, files_dir))
+    }
+
+    args <- c(args,
+              "--variable", paste("pagedtablejs=", pagedtable_path, sep=""))
+  }
+
+  args
+}
+
 pandoc_html_highlight_args <- function(highlight,
                                        template,
                                        self_contained,
