@@ -90,6 +90,7 @@ pdf_document <- function(toc = FALSE,
                          fig_crop = TRUE,
                          fig_caption = TRUE,
                          dev = 'pdf',
+                         df_print = "default",
                          highlight = "default",
                          template = "default",
                          keep_tex = FALSE,
@@ -226,6 +227,7 @@ pdf_document <- function(toc = FALSE,
                             latex_engine = latex_engine,
                             keep_tex = keep_tex),
     clean_supporting = !keep_tex,
+    df_print = df_print,
     pre_processor = pre_processor,
     intermediates_generator = intermediates_generator
   )
