@@ -360,6 +360,9 @@ copyable_site_resources <- function(input,
   excludes <- c("^rsconnect$", "^\\..*$", "^_.*$", "^.*_cache$",
                 extensions_regex,
                 utils::glob2rx(config$exclude))
+  # add ouput_dir to excludes if it's not '.'
+  if (config$output_dir != '.')
+    excludes <- c(excludes, config$output_dir)
   files <- all_files
   for (exclude in excludes)
     files <- files[!grepl(exclude, files)]
