@@ -46,6 +46,7 @@ slidy_presentation <- function(incremental = FALSE,
                                fig_retina = 2,
                                fig_caption = TRUE,
                                dev = 'png',
+                               df_print = "default",
                                smart = TRUE,
                                self_contained = TRUE,
                                highlight = "default",
@@ -90,6 +91,15 @@ slidy_presentation <- function(incremental = FALSE,
   # content includes
   args <- c(args, includes_to_pandoc_args(includes))
 
+  # pagedtables
+  if (identical(df_print, "paged")) {
+    pagedtable_path <- rmarkdown_system_file("rmd/h/pagedtable-0.0.1")
+    pagedtable_path <- pandoc_path_arg(pagedtable_path)
+
+    args <- c(args,
+              "--variable", paste("pagedtablejs=", pagedtable_path, sep=""))
+  }
+
   # additional css
   for (css_file in css)
     args <- c(args, "--css", pandoc_path_arg(css_file))
@@ -131,6 +141,7 @@ slidy_presentation <- function(incremental = FALSE,
                             args = args),
     keep_md = keep_md,
     clean_supporting = self_contained,
+    df_print = df_print,
     pre_processor = pre_processor,
     base_format = html_document_base(smart = smart, lib_dir = lib_dir,
                                      self_contained = self_contained,
